.nav-color{
    background-color: #EEEEEE;
}

.nav-margin{
    margin-left: -25px;
    margin-right: -25px;
}

#collapseForm{
    background-color: #EEEEEE;
}

#vue-app {
    margin-left: -36px;
    margin-right: -36px;
}

label::after{
    content: "" !important;
}

.pontilhado-meta{
    border-style: dashed;
    border-color: #0A5190;
    background-color: rgb(183, 234, 238);
    padding: 16px;
    padding-left: 60px;
    padding-right: 60px;
    color: #0A5190;
}

.pontilhado-recursos{
    border-style: dashed;
    border-color: #0A5190;
    background-color: rgb(183, 234, 238);
    color: #0A5190;
}

.add-meta{
    padding: 10px;
}

input::placeholder{
    color:#9ea2b0;
}

#btn-coluna{
    padding: 0%!important;
}

.input-style{
    width: 10rem!important;
    padding-top: 4%!important;
    border-color: #6d7278!important;
    background-color: #6d7278!important;
    color: white!important;
}

.margin-preview{
    margin-left:-17px!important;
    margin-right: -17px!important;
    margin-top: -17px!important;
}

.required {
    color: #dc3545;
}

.loading-container {
    position: absolute;
    top: 0px;
    left: 0px;
    right: 0px;
    bottom: 0px;
    text-align: center;
}
.loading-container .loading-backdrop {
    position: fixed;
    top: 0;
    left: 0;
    height: 100%;
    width: 100%;
    background-color: lightgray;
    opacity: 0.5;
    z-index: 9998;
}
.loading-container .loading {
    z-index: 9999;
    position: fixed;
    display: inline-block;
    background-color: white;
    padding: 20px 50px;
    border-radius: 12px;
    box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.19);
    left: 50%;
    top: 50%;
    -ms-transform: translate(-50%,-50%);
    -moz-transform: translate(-50%,-50%);
    -webkit-transform: translate(-50%,-50%);
    transform: translate(-50%,-50%);
}

.loading-container .loading .loading-icon {
    margin-bottom: 8px;
}

.file-icon {
    font-size: 3em;
}

#livemark-main {
    padding: 24px 20px;
    min-height: 100vh;
  }
  
  #livemark-main h1 {
    margin-top: 4px !important;
    padding-bottom: 12px !important;
  }
  
  #livemark-main h1 a.heading,
  #livemark-main h2 a.heading,
  #livemark-main h3 a.heading,
  #livemark-main h4 a.heading,
  #livemark-main h5 a.heading,
  #livemark-main h6 a.heading {
    display: none;
  }
  
  #livemark-main h2:hover a.heading,
  #livemark-main h3:hover a.heading,
  #livemark-main h4:hover a.heading,
  #livemark-main h5:hover a.heading,
  #livemark-main h6:hover a.heading {
    display: inline;
    margin-left: 8px;
    color: #aaa;
    font-weight: normal;
    text-decoration: none;
  }
  
  #livemark-main h2 a.heading:hover,
  #livemark-main h3 a.heading:hover,
  #livemark-main h4 a.heading:hover,
  #livemark-main h5 a.heading:hover,
  #livemark-main h6 a.heading:hover {
    text-decoration: underline;
  }
  
  #livemark-main .octicon {
    display: inline-block;
    fill: currentColor;
    vertical-align: text-bottom;
  }
  
  #livemark-main .anchor {
    float: left;
    line-height: 1;
    margin-left: -20px;
    padding-right: 4px;
  }
  
  #livemark-main .anchor:focus {
    outline: none;
  }
  
  #livemark-main h1 .octicon-link,
  #livemark-main h2 .octicon-link,
  #livemark-main h3 .octicon-link,
  #livemark-main h4 .octicon-link,
  #livemark-main h5 .octicon-link,
  #livemark-main h6 .octicon-link {
    color: #1b1f23;
    vertical-align: middle;
    visibility: hidden;
  }
  
  #livemark-main h1:hover .anchor,
  #livemark-main h2:hover .anchor,
  #livemark-main h3:hover .anchor,
  #livemark-main h4:hover .anchor,
  #livemark-main h5:hover .anchor,
  #livemark-main h6:hover .anchor {
    text-decoration: none;
  }
  
  #livemark-main h1:hover .anchor .octicon-link,
  #livemark-main h2:hover .anchor .octicon-link,
  #livemark-main h3:hover .anchor .octicon-link,
  #livemark-main h4:hover .anchor .octicon-link,
  #livemark-main h5:hover .anchor .octicon-link,
  #livemark-main h6:hover .anchor .octicon-link {
    visibility: visible;
  }
  
  #livemark-main h1:hover .anchor .octicon-link:before,
  #livemark-main h2:hover .anchor .octicon-link:before,
  #livemark-main h3:hover .anchor .octicon-link:before,
  #livemark-main h4:hover .anchor .octicon-link:before,
  #livemark-main h5:hover .anchor .octicon-link:before,
  #livemark-main h6:hover .anchor .octicon-link:before {
    width: 16px;
    height: 16px;
    content: ' ';
    display: inline-block;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' version='1.1' width='16' height='16' aria-hidden='true'%3E%3Cpath fill-rule='evenodd' d='M4 9h1v1H4c-1.5 0-3-1.69-3-3.5S2.55 3 4 3h4c1.45 0 3 1.69 3 3.5 0 1.41-.91 2.72-2 3.25V8.59c.58-.45 1-1.27 1-2.09C10 5.22 8.98 4 8 4H4c-.98 0-2 1.22-2 2.5S3 9 4 9zm9-3h-1v1h1c1 0 2 1.22 2 2.5S13.98 12 13 12H9c-.98 0-2-1.22-2-2.5 0-.83.42-1.64 1-2.09V6.25c-1.09.53-2 1.84-2 3.25C6 11.31 7.55 13 9 13h4c1.45 0 3-1.69 3-3.5S14.5 6 13 6z'%3E%3C/path%3E%3C/svg%3E");
  }
  
  #livemark-main {
    -ms-text-size-adjust: 100%;
    -webkit-text-size-adjust: 100%;
    line-height: 1.5;
    color: #222;
    font-family: Roboto, system-ui, -apple-system,BlinkMacSystemFont,Segoe UI,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;
    line-height: 1.5;
    word-wrap: break-word;
  }
  
  #livemark-main details {
    display: block;
  }
  
  #livemark-main summary {
    display: list-item;
  }
  
  #livemark-main a {
    background-color: initial;
  }
  
  #livemark-main a:active,
  #livemark-main a:hover {
    outline-width: 0;
  }
  
  #livemark-main strong {
    font-weight: inherit;
    font-weight: bolder;
  }
  
  #livemark-main h1 {
    font-size: 2em;
    margin: .67em 0;
  }
  
  #livemark-main img {
    border-style: none;
  }
  
  #livemark-main code,
  #livemark-main kbd,
  #livemark-main pre {
    font-family: monospace,monospace;
    font-size: 1em;
  }
  
  #livemark-main hr {
    box-sizing: initial;
    height: 0;
    overflow: visible;
  }
  
  #livemark-main input {
    font: inherit;
    margin: 0;
  }
  
  #livemark-main input {
    overflow: visible;
  }
  
  #livemark-main [type=checkbox] {
    box-sizing: border-box;
    padding: 0;
  }
  
  #livemark-main * {
    box-sizing: border-box;
  }
  
  #livemark-main input {
    font-family: inherit;
    font-size: inherit;
    line-height: inherit;
  }
  
  #livemark-main a {
    color: #0366d6;
    text-decoration: none;
  }
  
  #livemark-main a:hover {
    text-decoration: underline;
  }
  
  #livemark-main strong {
    font-weight: 600;
  }
  
  #livemark-main hr {
    height: 0;
    margin: 15px 0;
    overflow: hidden;
    background: transparent;
    border: 0;
    border-bottom: 1px solid #dfe2e5;
  }
  
  #livemark-main hr:after,
  #livemark-main hr:before {
    display: table;
    content: "";
  }
  
  #livemark-main hr:after {
    clear: both;
  }
  
  /* NOTE: is it possible to find a better fix for not breaking TablePlugin's styles? */
  #livemark-main table:not(.dataTable) {
    border-spacing: 0;
    border-collapse: collapse;
  }
  
  #livemark-main td,
  #livemark-main th {
    padding: 0;
  }
  
  #livemark-main details summary {
    cursor: pointer;
  }
  
  #livemark-main kbd {
    display: inline-block;
    padding: 3px 5px;
    font: 11px SFMono-Regular,Consolas,Liberation Mono,Menlo,monospace;
    line-height: 10px;
    color: #444d56;
    vertical-align: middle;
    background-color: #fafbfc;
    border: 1px solid #d1d5da;
    border-radius: 3px;
    box-shadow: inset 0 -1px 0 #d1d5da;
  }
  
  #livemark-main h1,
  #livemark-main h2,
  #livemark-main h3,
  #livemark-main h4,
  #livemark-main h5,
  #livemark-main h6 {
    margin-top: 0;
    margin-bottom: 0;
  }
  
  #livemark-main h1 {
    font-size: 32px;
  }
  
  #livemark-main h1,
  #livemark-main h2 {
    font-weight: 600;
  }
  
  #livemark-main h2 {
    font-size: 24px;
  }
  
  #livemark-main h3 {
    font-size: 20px;
  }
  
  #livemark-main h3,
  #livemark-main h4 {
    font-weight: 600;
  }
  
  #livemark-main h4 {
    font-size: 16px;
  }
  
  #livemark-main h5 {
    font-size: 14px;
  }
  
  #livemark-main h5,
  #livemark-main h6 {
    font-weight: 600;
  }
  
  #livemark-main h6 {
    font-size: 12px;
  }
  
  #livemark-main p {
    margin-top: 0;
    margin-bottom: 10px;
  }
  
  #livemark-main blockquote {
    margin: 0;
  }
  
  #livemark-main ol,
  #livemark-main ul {
    padding-left: 0;
    margin-top: 0;
    margin-bottom: 0;
  }
  
  #livemark-main ol ol,
  #livemark-main ul ol {
    list-style-type: lower-roman;
  }
  
  #livemark-main ol ol ol,
  #livemark-main ol ul ol,
  #livemark-main ul ol ol,
  #livemark-main ul ul ol {
    list-style-type: lower-alpha;
  }
  
  #livemark-main dd {
    margin-left: 0;
  }
  
  #livemark-main code,
  #livemark-main pre {
    font-family: SFMono-Regular,Consolas,Liberation Mono,Menlo,monospace;
    font-size: 12px;
  }
  
  #livemark-main pre {
    margin-top: 0;
    margin-bottom: 0;
  }
  
  #livemark-main input::-webkit-inner-spin-button,
  #livemark-main input::-webkit-outer-spin-button {
    margin: 0;
    -webkit-appearance: none;
    appearance: none;
  }
  
  #livemark-main :checked+.radio-label {
    position: relative;
    z-index: 1;
    border-color: #0366d6;
  }
  
  #livemark-main .border {
    border: 1px solid #e1e4e8!important;
  }
  
  #livemark-main .border-0 {
    border: 0!important;
  }
  
  #livemark-main .border-bottom {
    border-bottom: 1px solid #e1e4e8!important;
  }
  
  #livemark-main .rounded-1 {
    border-radius: 3px!important;
  }
  
  #livemark-main .bg-white {
    background-color: #fff!important;
  }
  
  #livemark-main .bg-gray-light {
    background-color: #fafbfc!important;
  }
  
  #livemark-main .text-gray-light {
    color: #666!important;
  }
  
  #livemark-main .mb-0 {
    margin-bottom: 0!important;
  }
  
  #livemark-main .my-2 {
    margin-top: 8px!important;
    margin-bottom: 8px!important;
  }
  
  #livemark-main .pl-0 {
    padding-left: 0!important;
  }
  
  #livemark-main .py-0 {
    padding-top: 0!important;
    padding-bottom: 0!important;
  }
  
  #livemark-main .pl-1 {
    padding-left: 4px!important;
  }
  
  #livemark-main .pl-2 {
    padding-left: 8px!important;
  }
  
  #livemark-main .py-2 {
    padding-top: 8px!important;
    padding-bottom: 8px!important;
  }
  
  #livemark-main .pl-3,
  #livemark-main .px-3 {
    padding-left: 16px!important;
  }
  
  #livemark-main .px-3 {
    padding-right: 16px!important;
  }
  
  #livemark-main .pl-4 {
    padding-left: 24px!important;
  }
  
  #livemark-main .pl-5 {
    padding-left: 32px!important;
  }
  
  #livemark-main .pl-6 {
    padding-left: 40px!important;
  }
  
  #livemark-main .f6 {
    font-size: 12px!important;
  }
  
  #livemark-main .lh-condensed {
    line-height: 1.25!important;
  }
  
  #livemark-main .text-bold {
    font-weight: 600!important;
  }
  
  #livemark-main .pl-c {
    color: #666;
  }
  
  #livemark-main .pl-c1,
  #livemark-main .pl-s .pl-v {
    color: #005cc5;
  }
  
  #livemark-main .pl-e,
  #livemark-main .pl-en {
    color: #6f42c1;
  }
  
  #livemark-main .pl-s .pl-s1,
  #livemark-main .pl-smi {
    color: #222;
  }
  
  #livemark-main .pl-ent {
    color: #22863a;
  }
  
  #livemark-main .pl-k {
    color: #d73a49;
  }
  
  #livemark-main .pl-pds,
  #livemark-main .pl-s,
  #livemark-main .pl-s .pl-pse .pl-s1,
  #livemark-main .pl-sr,
  #livemark-main .pl-sr .pl-cce,
  #livemark-main .pl-sr .pl-sra,
  #livemark-main .pl-sr .pl-sre {
    color: #032f62;
  }
  
  #livemark-main .pl-smw,
  #livemark-main .pl-v {
    color: #e36209;
  }
  
  #livemark-main .pl-bu {
    color: #b31d28;
  }
  
  #livemark-main .pl-ii {
    color: #fafbfc;
    background-color: #b31d28;
  }
  
  #livemark-main .pl-c2 {
    color: #fafbfc;
    background-color: #d73a49;
  }
  
  #livemark-main .pl-c2:before {
    content: "^M";
  }
  
  #livemark-main .pl-sr .pl-cce {
    font-weight: 700;
    color: #22863a;
  }
  
  #livemark-main .pl-ml {
    color: #735c0f;
  }
  
  #livemark-main .pl-mh,
  #livemark-main .pl-mh .pl-en,
  #livemark-main .pl-ms {
    font-weight: 700;
    color: #005cc5;
  }
  
  #livemark-main .pl-mi {
    font-style: italic;
    color: #222;
  }
  
  #livemark-main .pl-mb {
    font-weight: 700;
    color: #222;
  }
  
  #livemark-main .pl-md {
    color: #b31d28;
    background-color: #ffeef0;
  }
  
  #livemark-main .pl-mi1 {
    color: #22863a;
    background-color: #f0fff4;
  }
  
  #livemark-main .pl-mc {
    color: #e36209;
    background-color: #ffebda;
  }
  
  #livemark-main .pl-mi2 {
    color: #f6f8fa;
    background-color: #005cc5;
  }
  
  #livemark-main .pl-mdr {
    font-weight: 700;
    color: #6f42c1;
  }
  
  #livemark-main .pl-ba {
    color: #586069;
  }
  
  #livemark-main .pl-sg {
    color: #959da5;
  }
  
  #livemark-main .pl-corl {
    text-decoration: underline;
    color: #032f62;
  }
  
  #livemark-main .mb-0 {
    margin-bottom: 0!important;
  }
  
  #livemark-main .my-2 {
    margin-bottom: 8px!important;
  }
  
  #livemark-main .my-2 {
    margin-top: 8px!important;
  }
  
  #livemark-main .pl-0 {
    padding-left: 0!important;
  }
  
  #livemark-main .py-0 {
    padding-top: 0!important;
    padding-bottom: 0!important;
  }
  
  #livemark-main .pl-1 {
    padding-left: 4px!important;
  }
  
  #livemark-main .pl-2 {
    padding-left: 8px!important;
  }
  
  #livemark-main .py-2 {
    padding-top: 8px!important;
    padding-bottom: 8px!important;
  }
  
  #livemark-main .pl-3 {
    padding-left: 16px!important;
  }
  
  #livemark-main .pl-4 {
    padding-left: 24px!important;
  }
  
  #livemark-main .pl-5 {
    padding-left: 32px!important;
  }
  
  #livemark-main .pl-6 {
    padding-left: 40px!important;
  }
  
  #livemark-main .pl-7 {
    padding-left: 48px!important;
  }
  
  #livemark-main .pl-8 {
    padding-left: 64px!important;
  }
  
  #livemark-main .pl-9 {
    padding-left: 80px!important;
  }
  
  #livemark-main .pl-10 {
    padding-left: 96px!important;
  }
  
  #livemark-main .pl-11 {
    padding-left: 112px!important;
  }
  
  #livemark-main .pl-12 {
    padding-left: 128px!important;
  }
  
  #livemark-main hr {
    border-bottom-color: #eee;
  }
  
  #livemark-main kbd {
    display: inline-block;
    padding: 3px 5px;
    font: 11px SFMono-Regular,Consolas,Liberation Mono,Menlo,monospace;
    line-height: 10px;
    color: #444d56;
    vertical-align: middle;
    background-color: #fafbfc;
    border: 1px solid #d1d5da;
    border-radius: 3px;
    box-shadow: inset 0 -1px 0 #d1d5da;
  }
  
  #livemark-main:after,
  #livemark-main:before {
    display: table;
    content: "";
  }
  
  #livemark-main:after {
    clear: both;
  }
  
  #livemark-main a:not([href]) {
    color: inherit;
    text-decoration: none;
  }
  
  #livemark-main blockquote,
  #livemark-main details,
  #livemark-main dl,
  #livemark-main ol,
  #livemark-main p,
  #livemark-main pre,
  #livemark-main table:not(.dataTable),
  #livemark-main ul {
    margin-top: 0;
    margin-bottom: 16px;
  }
  
  #livemark-main hr {
    /* height: .25em; */
    height: 1px;
    padding: 0;
    margin: 24px 0;
    background-color: #e1e4e8;
    border: 0;
  }
  
  #livemark-main blockquote {
    padding: 0 1em;
    color: #666;
    border-left: .25em solid #dfe2e5;
  }
  
  #livemark-main blockquote>:first-child {
    margin-top: 0;
  }
  
  #livemark-main blockquote>:last-child {
    margin-bottom: 0;
  }
  
  #livemark-main h1,
  #livemark-main h2,
  #livemark-main h3,
  #livemark-main h4,
  #livemark-main h5,
  #livemark-main h6 {
    margin-top: 24px;
    margin-bottom: 16px;
    font-weight: 600;
    line-height: 1.25;
  }
  
  #livemark-main h1 {
    font-size: 2em;
  }
  
  #livemark-main h1,
  #livemark-main h2 {
    padding-bottom: .3em;
    border-bottom: 1px solid #eaecef;
  }
  
  #livemark-main h2 {
    font-size: 1.5em;
  }
  
  #livemark-main h3 {
    font-size: 1.25em;
  }
  
  #livemark-main h4 {
    font-size: 1em;
  }
  
  #livemark-main h5 {
    font-size: .875em;
  }
  
  #livemark-main h6 {
    font-size: .85em;
    color: #666;
  }
  
  #livemark-main ol,
  #livemark-main ul {
    padding-left: 2em;
  }
  
  #livemark-main ol ol,
  #livemark-main ol ul,
  #livemark-main ul ol,
  #livemark-main ul ul {
    margin-top: 0;
    margin-bottom: 0;
  }
  
  #livemark-main li {
    word-wrap: break-all;
  }
  
  #livemark-main li>p {
    margin-top: 16px;
  }
  
  #livemark-main li+li {
    margin-top: .25em;
  }
  
  #livemark-main dl {
    padding: 0;
  }
  
  #livemark-main dl dt {
    padding: 0;
    margin-top: 16px;
    font-size: 1em;
    font-style: italic;
    font-weight: 600;
  }
  
  #livemark-main dl dd {
    padding: 0 16px;
    margin-bottom: 16px;
  }
  
  #livemark-main table:not(.dataTable) {
    display: block;
    width: 100%;
    overflow: auto;
  }
  
  #livemark-main table:not(.dataTable) th {
    font-weight: 600;
  }
  
  #livemark-main table:not(.dataTable) td,
  #livemark-main table:not(.dataTable) th {
    padding: 6px 13px;
    border: 1px solid #dfe2e5;
  }
  
  #livemark-main table:not(.dataTable) tr {
    background-color: #fff;
    border-top: 1px solid #c6cbd1;
  }
  
  #livemark-main table:not(.dataTable) tr:nth-child(2n) {
    background-color: #f6f8fa;
  }
  
  #livemark-main img {
    max-width: 100%;
    box-sizing: initial;
    background-color: #fff;
  }
  
  #livemark-main img[align=right] {
    padding-left: 20px;
  }
  
  #livemark-main img[align=left] {
    padding-right: 20px;
  }
  
  #livemark-main code {
    padding: .2em .4em;
    margin: 0;
    font-size: 85%;
    background-color: rgba(27,31,35,.05);
    border-radius: 3px;
  }
  
  #livemark-main pre {
    word-wrap: normal;
  }
  
  #livemark-main pre>code {
    padding: 0;
    margin: 0;
    font-size: 100%;
    word-break: normal;
    white-space: pre;
    background: transparent;
    border: 0;
  }
  
  #livemark-main .highlight {
    margin-bottom: 16px;
  }
  
  #livemark-main .highlight pre {
    margin-bottom: 0;
    word-break: normal;
  }
  
  #livemark-main .highlight pre,
  #livemark-main pre {
    padding: 16px;
    overflow: auto;
    font-size: 85%;
    line-height: 1.45;
    background-color: #f6f8fa;
    border-radius: 3px;
  }
  
  #livemark-main pre code {
    display: inline;
    max-width: auto;
    padding: 0;
    margin: 0;
    overflow: visible;
    line-height: inherit;
    word-wrap: normal;
    background-color: initial;
    border: 0;
  }
  
  #livemark-main .commit-tease-sha {
    display: inline-block;
    font-family: SFMono-Regular,Consolas,Liberation Mono,Menlo,monospace;
    font-size: 90%;
    color: #444d56;
  }
  
  #livemark-main .full-commit .btn-outline:not(:disabled):hover {
    color: #005cc5;
    border-color: #005cc5;
  }
  
  #livemark-main .blob-wrapper {
    overflow-x: auto;
    overflow-y: hidden;
  }
  
  #livemark-main .blob-wrapper-embedded {
    max-height: 240px;
    overflow-y: auto;
  }
  
  #livemark-main .blob-num {
    width: 1%;
    min-width: 50px;
    padding-right: 10px;
    padding-left: 10px;
    font-family: SFMono-Regular,Consolas,Liberation Mono,Menlo,monospace;
    font-size: 12px;
    line-height: 20px;
    color: rgba(27,31,35,.3);
    text-align: right;
    white-space: nowrap;
    vertical-align: top;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
  }
  
  #livemark-main .blob-num:hover {
    color: rgba(27,31,35,.6);
  }
  
  #livemark-main .blob-num:before {
    content: attr(data-line-number);
  }
  
  #livemark-main .blob-code {
    position: relative;
    padding-right: 10px;
    padding-left: 10px;
    line-height: 20px;
    vertical-align: top;
  }
  
  #livemark-main .blob-code-inner {
    overflow: visible;
    font-family: SFMono-Regular,Consolas,Liberation Mono,Menlo,monospace;
    font-size: 12px;
    color: #222;
    word-wrap: normal;
    white-space: pre;
  }
  
  #livemark-main .pl-token.active,
  #livemark-main .pl-token:hover {
    cursor: pointer;
    background: #ffea7f;
  }
  
  #livemark-main .tab-size[data-tab-size="1"] {
    -moz-tab-size: 1;
    tab-size: 1;
  }
  
  #livemark-main .tab-size[data-tab-size="2"] {
    -moz-tab-size: 2;
    tab-size: 2;
  }
  
  #livemark-main .tab-size[data-tab-size="3"] {
    -moz-tab-size: 3;
    tab-size: 3;
  }
  
  #livemark-main .tab-size[data-tab-size="4"] {
    -moz-tab-size: 4;
    tab-size: 4;
  }
  
  #livemark-main .tab-size[data-tab-size="5"] {
    -moz-tab-size: 5;
    tab-size: 5;
  }
  
  #livemark-main .tab-size[data-tab-size="6"] {
    -moz-tab-size: 6;
    tab-size: 6;
  }
  
  #livemark-main .tab-size[data-tab-size="7"] {
    -moz-tab-size: 7;
    tab-size: 7;
  }
  
  #livemark-main .tab-size[data-tab-size="8"] {
    -moz-tab-size: 8;
    tab-size: 8;
  }
  
  #livemark-main .tab-size[data-tab-size="9"] {
    -moz-tab-size: 9;
    tab-size: 9;
  }
  
  #livemark-main .tab-size[data-tab-size="10"] {
    -moz-tab-size: 10;
    tab-size: 10;
  }
  
  #livemark-main .tab-size[data-tab-size="11"] {
    -moz-tab-size: 11;
    tab-size: 11;
  }
  
  #livemark-main .tab-size[data-tab-size="12"] {
    -moz-tab-size: 12;
    tab-size: 12;
  }
  
  #livemark-main .task-list-item {
    list-style-type: none;
  }
  
  #livemark-main .task-list-item+.task-list-item {
    margin-top: 3px;
  }
  
  #livemark-main .task-list-item input {
    margin: 0 .2em .25em -1.6em;
    vertical-align: middle;
  }
  
  /* Left */
  
  #livemark-left {
    visibility: hidden;
    position: fixed;
    width: 300px;
    padding: 10px 40px;
    padding-bottom: 100px;
    left: 0px;
    top: 25px;
    font-size: 125%;
    height: 100vh;
    overflow-y: auto;
    scrollbar-width: none;  /* Firefox */
    -ms-overflow-style: none;  /* Internet Explorer 10+ */
  }
  
  /* NOTE: we need to move it to DisplayPlugin (currently unsetting doesn't work) */
  body:not(.with-readability) #livemark-left::-webkit-scrollbar {
    display: none; /* Chrome; Safari */
  }
  
  #livemark-left > div:not(:last-child) {
    border-bottom: 1px solid #eaecef;
    padding-bottom: 15px;
    margin-bottom: 15px;
  }
  
  @media only screen and (min-width: 768px) {
    #livemark-left {
      visibility: visible;
    }
  }
  
  /* Right */
  
  #livemark-right {
    visibility: hidden;
    position: fixed;
    width: 300px;
    padding: 10px 40px;
    padding-bottom: 100px;
    right: 0px;
    top: 25px;
    font-size: 125%;
    height: 100vh;
    overflow-y: auto;
    scrollbar-width: none;  /* Firefox */
    -ms-overflow-style: none;  /* Internet Explorer 10+ */
  }
  
  /* NOTE: we need to move it to DisplayPlugin (currently unsetting doesn't work) */
  body:not(.with-readability) #livemark-right::-webkit-scrollbar {
    display: none; /* Chrome; Safari */
  }
  
  #livemark-right > div:not(:last-child) {
    border-bottom: 1px solid #eaecef;
    padding-bottom: 15px;
    margin-bottom: 15px;
  }
  
  @media only screen and (min-width: 992px) {
    #livemark-right {
      visibility: visible;
    }
  }
  
  
  
  
  #livemark-brand {
    color: #888;
  }
  
  #livemark-brand ul {
    overflow: hidden;
    position: relative;
    padding-left: 0;
    margin: 0;
  }
  
  #livemark-brand li {
    list-style: none;
  }
  
  #livemark-brand a {
    display: inline-block;
    color: currentColor;
    position: relative;
    width: 100%;
    line-height: 100%;
    padding-top: 5px;
    padding-bottom: 5px;
  }
  
  #livemark-brand a.active {
    font-weight: 700;
  }
  
  #livemark-brand a:hover {
    color: #80b2e6;
  }
    
  .livemark-reference {
    display: block;
    /* font-family: ui-monospace, Menlo, Monaco, "Cascadia Mono", "Segoe UI Mono", "Roboto Mono", "Oxygen Mono", "Ubuntu Monospace", "Source Code Pro", "Fira Mono", "Droid Sans Mono", "Courier New", monospace;; */
  }
  
  .livemark-reference-heading {
      background-color: #f6f8fa;
      font-family: "Roboto Mono", ui-monospace, monospace;
      padding: 1em 0;
  }  
  
  #livemark-notes {
    color: #aaa;
    text-align: right;
    font-size: 14px;
    float: right;
    visibility: hidden;
  }
  
  @media (min-width: 768px) {
    #livemark-notes {
      visibility: visible;
    }
  }
  
  #livemark-notes a {
    color: inherit;
  }
  
  #livemark-notes a:hover {
    color: #80b2e6;
  }
  
  #livemark-notes a[target="_blank"]:after {
    content: "\f35d";
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    vertical-align: text-top;
    text-decoration: none;
    display: inline-block;
    color: #ccc;
    font-size: 10px;
    margin-left: -1px;
  }
  
  #livemark-notes a[target="_blank"]:hover:after {
    color: #80b2e6;
  }
  
  
  
  
  #livemark-rating {
    height: 46px;
  }
  
  #livemark-rating iframe {
    margin-top: -5px;
    border: none;
    opacity: 0.5;
  }
  
  
  
  
  #livemark-topics {
    color: #888;
  }
  
  #livemark-topics .toc>.toc-list {
    overflow: hidden;
    position: relative;
  }
  
  #livemark-topics .toc>.toc-list li {
    list-style: none;
  }
  
  #livemark-topics .toc-list {
    padding-left: 0;
    margin: 0;
  }
  
  #livemark-topics a.toc-link {
    color: currentColor;
  }
  
  #livemark-topics a.toc-link:hover {
    color: #80b2e6;
  }
  
  #livemark-topics .is-active-link {
    font-weight: 700;
  }
  
  #livemark-topics ul.secondary {
    margin-left: 20px;
    display: none;
  }
  
  #livemark-topics li.is-active-li ul.secondary {
    display: block;
  }
  
  #livemark-topics li.group a.primary::after {
    content: "\f054";
    font-size: 16px;
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    position: absolute;
    top: 2px;
    right: 0px;
  }
  
  #livemark-topics li.group.is-active-li a.primary::after {
    content: "\f078";
  }
  
  #livemark-topics a {
    display: inline-block;
    color: currentColor;
    position: relative;
    width: 100%;
    line-height: 100%;
    padding-top: 5px;
    padding-bottom: 5px;
  }
  
  #livemark-topics a:hover {
    color: #80b2e6;
  }
  
  
  
  
  .livemark-audio {
    padding-bottom: 10px;
  }
  
  
  
  
  .livemark-blog-item {
    margin-bottom: 16px;
    text-align: justify;
  }
  
  .livemark-blog-item h2 a:not(.heading) {
    color: #222 !important;
  }
  
  
  
  
  #livemark-cards .modal-lg {
      max-width: 1000px;
  }
  
  
  
  
  #livemark-display {
    display: flex;
    position: fixed;
    visibility: hidden;
    justify-content: space-between;
    font-size: 16px;
    color: #888;
    width: 240px;
    bottom: 20px;
    right: 30px;
  }
  
  @media only screen and (min-width: 992px) {
    #livemark-display {
      visibility: visible;
    }
  }
  
  #livemark-display .control {
    cursor: pointer;
    background-color:#fff;
    box-shadow: 0px 7px 10px #eee;
    border-radius: 50%;
    border: solid 1px #ddd;
    z-index: 100;
  }
  
  #livemark-display .control .fa {
    display: inline-block !important;
    opacity: 1 !important;
    padding: 15px;
  }
  
  .with-readability {
    font-size: 20px;
  }
  
  .with-readability #livemark-main {
    color: #000;
  }
  
  .with-readability #livemark-left > *,
  .with-readability #livemark-right > * {
    color: #444;
  }
  
  .with-readability #livemark-left,
  .with-readability #livemark-right {
    scrollbar-width: unset;  /* Firefox */
    -ms-overflow-style: unset;  /* Internet Explorer 10+ */
  }
  
  /* NOTE: */
  /* temporarily implemented in HtmlPlugin */
  /* .with-readability #livemark-left::-webkit-scrollbar, */
  /* .with-readability #livemark-right::-webkit-scrollbar { */
    /* display: unset !important; [> Chrome; Safari <] */
  /* } */
  
  
  
  
  .livemark-image {
    padding-bottom: 10px;
  }
  
  
  
  
  .livemark-infinity {
    display: none;
  }
  
  
  
  
  #livemark-mobile {
    position: absolute;
    visibility: hidden;
    z-index: 10000;
    /* NOTE: We can't use "right" because of Mobile Chrome and #34 */
    left: calc(100vw - 60px);
    top: 24px;
  }
  
  #livemark-mobile .stack {
    margin-top: 15px;
    display: block;
    cursor: pointer;
  }
  
  #livemark-mobile .bar {
    display: block;
    width: 25px;
    height: 3px;
    margin: 5px auto;
    -webkit-transition: all 0.3s ease-in-out;
    transition: all 0.3s ease-in-out;
    background-color: #aaa;
  }
  
  @media only screen and (max-width: 768px) {
    #livemark-mobile {
      visibility: visible;
    }
  
    #livemark-mobile.active {
      position: fixed;
    }
  
    #livemark-mobile.active .bar:nth-child(2) {
      opacity: 0;
    }
  
    #livemark-mobile.active .bar:nth-child(1) {
      transform: translateY(8px) rotate(45deg);
    }
  
    #livemark-mobile.active .bar:nth-child(3) {
      transform: translateY(-8px) rotate(-45deg);
    }
  
    #livemark-left {
        position: fixed;
        top: 0;
        left: -100vw;
        padding-top: 35px;
        background-color: #fff;
        width: 100vw;
        border-radius: 10px;
        text-align: center;
        transition: 0.3s;
        box-shadow: 0 10px 27px rgba(0, 0, 0, 0.05);
        visibility: visible;
        z-index: 1000;
    }
  
    #livemark-left.active {
      left: 0;
    }
  }